@@ -2,6 +2,7 @@ use 5.012;
 use MooseX::Declare;
 use Method::Signatures::Modifiers;
 
+# PODNAME: Dist::Zilla::PluginBundle::BAREFOOT
 class Dist::Zilla::PluginBundle::BAREFOOT with Dist::Zilla::Role::PluginBundle::Easy
 {
 	use autodie										2.00					;
@@ -34,11 +35,11 @@ class Dist::Zilla::PluginBundle::BAREFOOT with Dist::Zilla::Role::PluginBundle::
 	use Dist::Zilla::Plugin::CheckVersionIncrement	0.121750	();
 	#use Dist::Zilla::Plugin::MetaProvides::Package	1.14		();		# hides DB/main/private packages
 	use Dist::Zilla::Plugin::MetaProvides::Class	2.001		();		# adds 'provides' to META.* for `class`
-	use Dist::Zilla::Plugin::PodnameFromClassname				();		# stops Pod::Weaver from complaining
+	use Dist::Zilla::Plugin::PodnameFromClassname	0.1100		();		# stops Pod::Weaver from complaining
 	use Dist::Zilla::Plugin::CheckChangesHasContent				();
 
 
-	our $VERSION = '0.04_02'; # TRIAL VERSION
+	our $VERSION = '0.06_01'; # TRIAL VERSION
 
 	my @dirty_files = qw< dist.ini Changes >;
 	my @exclude_generated_files = qw< README.pod META.json >;
@@ -183,7 +184,7 @@ Dist::Zilla::PluginBundle::BAREFOOT - Dist::Zilla configuration the way BAREFOOT
 
 =head1 VERSION
 
-This document describes version 0.04_02 of Dist::Zilla::PluginBundle::BAREFOOT.
+This document describes version 0.06_01 of Dist::Zilla::PluginBundle::BAREFOOT.
 
 =head1 SYNOPSIS
 
@@ -385,7 +386,7 @@ You can find documentation for this module with the perldoc command.
 		likely to get accepted (or least likely to get accepted more quickly).
 
 		If you just want to report a problem or suggest a feature, that's okay too.  You can create
-		an issue on GitHub here: L<http://github.com/me/dist-zilla-pluginbundle-barefoot/issues>.
+		an issue on GitHub here: L<http://github.com/barefootcoder/dist-zilla-pluginbundle-barefoot/issues>.
 
 =head2 Source Code
 
